pub mod kill;
pub mod killable_channel;
pub mod lossy_channel;

pub static FAILED_TO_LOCK: &str = "Failed to acquire lock";
